@@ -1,20 +1,20 @@
 """
 Workflow which exercises the common tasks in an end to end scenario
 """
-from dkist_processing_common.tasks.l1_output_data import AddDatasetReceiptAccount
-from dkist_processing_common.tasks.l1_output_data import PublishCatalogAndQualityMessages
-from dkist_processing_common.tasks.l1_output_data import TransferL1Data
-from dkist_processing_common.tasks.quality_metrics import QualityL0Metrics
-from dkist_processing_common.tasks.quality_metrics import QualityL1Metrics
-from dkist_processing_common.tasks.submit_quality import SubmitQuality
-from dkist_processing_common.tasks.teardown import Teardown
-from dkist_processing_common.tasks.transfer_input_data import TransferL0Data
+from dkist_processing_common.tasks import AddDatasetReceiptAccount
+from dkist_processing_common.tasks import PublishCatalogAndQualityMessages
+from dkist_processing_common.tasks import QualityL1Metrics
+from dkist_processing_common.tasks import SubmitQuality
+from dkist_processing_common.tasks import Teardown
+from dkist_processing_common.tasks import TransferL0Data
+from dkist_processing_common.tasks import TransferL1Data
 from dkist_processing_core import Workflow
 
 from dkist_processing_test.tasks.fake_science import GenerateCalibratedData
 from dkist_processing_test.tasks.movie import AssembleTestMovie
 from dkist_processing_test.tasks.movie import MakeTestMovieFrames
 from dkist_processing_test.tasks.parse import ParseL0TestInputData
+from dkist_processing_test.tasks.quality import TestQualityL0Metrics
 from dkist_processing_test.tasks.write_l1 import WriteL1Data
 
 # TransferInputData Task
@@ -33,7 +33,7 @@ parse_input_data.add_node(task=ParseL0TestInputData, upstreams=None)
 quality_l0_metrics = Workflow(
     process_category="test", process_name="quality_l0_metrics", workflow_package=__package__
 )
-quality_l0_metrics.add_node(task=QualityL0Metrics, upstreams=None)
+quality_l0_metrics.add_node(task=TestQualityL0Metrics, upstreams=None)
 
 # L1Quality Task
 quality_l1_metrics = Workflow(
